
# This file was generated by 'versioneer.py' (0.14) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

version_version = '0.24.0+1.gee50a0f'
version_full = 'ee50a0f47d43ca2c4f286da193b17757f1c619e7'
def get_versions(default={}, verbose=False):
    return {'version': version_version, 'full': version_full}

